==> ui-react-1.0.84.tgz: package/esm/Labels/Labels.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "colorUnchecked", "version", "size", "name", "label", "direction", "align", "justify", "valueDefault", "checkedDefault", "value", "checked", "onChange", "disabled", "WrapperProps", "LabelProps", "Component", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is } from '@onesy/utils';
import { classNames, style as styleMethod, useOnesyTheme } from '@onesy/style-react';
import TypeElement from '../Type';
import LineElement from '../Line';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {},
  label_disabled: {
    opacity: theme.palette.visual_contrast.default.opacity.disabled
  },
  disabled: {
    cursor: 'default',
    userSelect: 'none'
  }
}), {
  name: 'onesy-Labels'
});
const Labels = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyLabels?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      colorUnchecked,
      version = 'text',
      size = 'regular',
      name,
      label: label_,
      direction = 'column',
      align = 'center',
      justify = 'center',
      valueDefault: valueDefault_,
      checkedDefault: checkedDefault_,
      value: value_,
      checked: checked_,
      onChange,
      disabled,
      WrapperProps,
      LabelProps,
      Component = 'div',
      className,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const checkedDefault = valueDefault_ !== undefined ? valueDefault_ : checkedDefault_;
  const checked = value_ !== undefined ? value_ : checked_;
  const valueDefault__ = (checkedDefault !== undefined ? checkedDefault : value_) || [];
  const [value, setValue] = React.useState(is('array', valueDefault__) ? valueDefault__ : [valueDefault__]);
  const refs = {
    value: React.useRef(undefined),
    ids: {
      label: React.useId()
    }
  };
  refs.value.current = value;
  const label = name !== undefined ? name : label_;
  React.useEffect(() => {
    if (checked !== undefined && checked !== refs.value.current) setValue(checked);
  }, [checked]);
  const children = React.Children.toArray(children_);
  const onUpdate = React.useCallback(valueNew_ => {
    const valueNew = valueNew_;
    const value__ = [...refs.value.current];
    const index = value__.findIndex(item => item === valueNew);
    if (index > -1) value__.splice(index, 1);else value__.push(valueNew);
    if (!props.hasOwnProperty('value')) setValue(value__);
    if (is('function', onChange)) onChange(value__);
  }, []);
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: ref,
    gap: 1,
    direction: direction,
    align: props.align !== undefined ? props.align : props.direction === 'row' ? 'center' : 'flex-start',
    justify: justify,
    role: "radiogroup",
    "aria-labelledby": refs.ids.label,
    Component: Component,
    className: classNames([staticClassName('Labels', theme) && ['onesy-Labels-root', `onesy-Labels-version-${version}`, `onesy-Labels-size-${size}`, `onesy-Labels-version-${version}`, disabled && `onesy-Labels-disabled`], className, classes.root, disabled && classes.disabled])
  }, other), label && /*#__PURE__*/React.createElement(Type, _extends({
    version: size === 'regular' ? 'l2' : size === 'large' ? 'l1' : 'l3',
    id: refs.ids.label
  }, LabelProps, {
    className: classNames([staticClassName('Labels', theme) && ['onesy-Labels-label'], LabelProps?.className, classes.label, disabled && classes.label_disabled])
  }), label), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 1,
    direction: direction,
    align: props.align !== undefined ? props.align : props.direction === 'row' ? 'center' : 'flex-start',
    justify: justify
  }, WrapperProps), children.map((item, index) => (/*#__PURE__*/React.cloneElement(item, {
    key: index,
    checked: value.includes(item.props.value),
    onChange: () => onUpdate(item.props.value),
    tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
    color: item.props.color !== undefined ? item.props.color : color,
    colorUnchecked: item.props.colorUnchecked !== undefined ? item.props.colorUnchecked : colorUnchecked,
    version: item.props.version !== undefined ? item.props.version : version,
    size: item.props.size !== undefined ? item.props.size : size,
    disabled: item.props.disabled !== undefined ? item.props.disabled : disabled
  })))));
});
Labels.displayName = 'onesy-Labels';
export default Labels;

==> ui-react-1.1.440.tgz: package/esm/Labels/Labels.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["tonal", "color", "colorUnchecked", "version", "size", "name", "label", "direction", "align", "justify", "valueDefault", "checkedDefault", "value", "checked", "onChange", "disabled", "WrapperProps", "LabelProps", "Component", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import TypeElement from '../Type';
import LineElement from '../Line';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {},
  label_disabled: {
    opacity: theme.palette.visual_contrast.default.opacity.disabled
  },
  disabled: {
    cursor: 'default',
    userSelect: 'none'
  }
}), {
  name: 'amaui-Labels'
});
const Labels = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiLabels?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const Type = React.useMemo(() => theme?.elements?.Type || TypeElement, [theme]);
  const {
      tonal = true,
      color = 'primary',
      colorUnchecked,
      version = 'text',
      size = 'regular',
      name,
      label: label_,
      direction = 'column',
      align = 'center',
      justify = 'center',
      valueDefault: valueDefault_,
      checkedDefault: checkedDefault_,
      value: value_,
      checked: checked_,
      onChange,
      disabled,
      WrapperProps,
      LabelProps,
      Component = 'div',
      className,
      children: children_
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const checkedDefault = valueDefault_ !== undefined ? valueDefault_ : checkedDefault_;
  const checked = value_ !== undefined ? value_ : checked_;
  const valueDefault__ = (checkedDefault !== undefined ? checkedDefault : value_) || [];
  const [value, setValue] = React.useState(is('array', valueDefault__) ? valueDefault__ : [valueDefault__]);
  const refs = {
    value: React.useRef(),
    ids: {
      label: React.useId()
    }
  };
  refs.value.current = value;
  const label = name !== undefined ? name : label_;
  React.useEffect(() => {
    if (checked !== undefined && checked !== refs.value.current) setValue(checked);
  }, [checked]);
  const children = React.Children.toArray(children_);
  const onUpdate = React.useCallback(valueNew_ => {
    const valueNew = valueNew_;
    const value__ = [...refs.value.current];
    const index = value__.findIndex(item => item === valueNew);
    if (index > -1) value__.splice(index, 1);else value__.push(valueNew);
    if (!props.hasOwnProperty('value')) setValue(value__);
    if (is('function', onChange)) onChange(value__);
  }, []);
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: ref,
    gap: 1,
    direction: direction,
    align: props.align !== undefined ? props.align : props.direction === 'row' ? 'center' : 'flex-start',
    justify: justify,
    role: "radiogroup",
    "aria-labelledby": refs.ids.label,
    Component: Component,
    className: classNames([staticClassName('Labels', theme) && ['amaui-Labels-root', `amaui-Labels-version-${version}`, disabled && `amaui-Labels-disabled`], className, classes.root, disabled && classes.disabled])
  }, other), /*#__PURE__*/React.createElement(Type, _extends({
    version: size === 'regular' ? 'l2' : size === 'large' ? 'l1' : 'l3',
    id: refs.ids.label
  }, LabelProps, {
    className: classNames([staticClassName('Labels', theme) && ['amaui-Labels-label'], LabelProps?.className, classes.label, disabled && classes.label_disabled])
  }), label), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 1,
    direction: direction,
    align: props.align !== undefined ? props.align : props.direction === 'row' ? 'center' : 'flex-start',
    justify: justify
  }, WrapperProps), children.map((item, index) => /*#__PURE__*/React.cloneElement(item, {
    key: index,
    checked: value.includes(item.props.value),
    onChange: () => onUpdate(item.props.value),
    tonal: item.props.tonal !== undefined ? item.props.tonal : tonal,
    color: item.props.color !== undefined ? item.props.color : color,
    colorUnchecked: item.props.colorUnchecked !== undefined ? item.props.colorUnchecked : colorUnchecked,
    version: item.props.version !== undefined ? item.props.version : version,
    size: item.props.size !== undefined ? item.props.size : size,
    disabled: item.props.disabled !== undefined ? item.props.disabled : disabled
  }))));
});
Labels.displayName = 'amaui-Labels';
export default Labels;
